@@ -4,7 +4,7 @@ use App::GHPT::Wrapper::Ourperl;
 
 use v5.20;
 
-our $VERSION = '1.000004';
+our $VERSION = '1.000005';
 
 1;
 
@@ -22,7 +22,7 @@ App::GHPT - A command line tool to simplify using Github and Pivotal Tracker for
 
 =head1 VERSION
 
-version 1.000004
+version 1.000005
 
 =head1 SYNOPSIS
 
@@ -111,6 +111,18 @@ You'll also need to tell git about your PT account:
 Your actual username and token can be found at
 L<https://www.pivotaltracker.com/profile>.
 
+=head1 CREATING PULL REQUEST QUESTIONS
+
+A question is a class which consumes the
+L<App::GHPT::WorkSubmitter::Role::Question> and implements a method named
+C<ask>. See that role's documentation for details.
+
+By default, this tools looks for modules that have a a package name beginning
+with C<App::GHPT::WorkSubmitter::Question> to find question classes. However,
+you can configure one or more alternative namespaces by setting the git config
+key C<submit-work.question-namespaces>. This should be a space-separated list
+of namespaces under which questions can live.
+
 =head1 COMMAND LINE OPTIONS
 
 This tool accepts the following options:
@@ -123,7 +135,7 @@ want to limit this to just one.
 
 =head2 --base branch
 
-The branch against which the PR should be made. This default to the master
+The branch against which the PR should be made. This defaults to the master
 branch.
 
 =head2 --dry-run
@@ -183,12 +195,16 @@ Dave Rolsky <autarch@urth.org>
 
 =head1 CONTRIBUTORS
 
-=for stopwords Greg Oschwald Mark Fowler
+=for stopwords Florian Ragwitz Greg Oschwald Mark Fowler
 
 =over 4
 
 =item *
 
+Florian Ragwitz <rafl@debian.org>
+
+=item *
+
 Greg Oschwald <goschwald@maxmind.com>
 
 =item *
